# SAC-Tello
A simple library for controlling a DJI Tello Drone. Built for educational use.

# Dependencies

> numpy version>=1.23.4
> 
> opencv-python version>=4.6.0.66
> 
> face_recognition version>=1.3.0